* Javier Martin Montull (https://github.com/jmartinm)
* Jiri Kuncar (https://github.com/jirikuncar)
* John Begeman (https://github.com/jawnb)
* Patrick Altman (https://github.com/paltman)
* Philippe Ombredanne (https://github.com/pombredanne)
* Steve Schwarz (https://github.com/saschwarz)
* Yoan Blanc (https://github.com/greut)
